/* -*- c++ -*-
 *
 *  Le Caviste --- a wine cellar managing application
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  For more information, visit the Le Caviste Home Page at
 *  http://www.lecaviste.org/
 *
 *  Copyright (c) 2007
 *      Le Caviste Authors <devel@lecaviste.org>
 *
 */
#include "csv_parser.hpp"

CSVParser::CSVParser(
	  const QString & sep, 
	  const QChar & textDelimiter) :
  m_separators(sep), m_textDelimiter(textDelimiter)
{
  setSeparator(sep);
}



bool CSVParser::parseLine(const QString & line, QStringList & list)
{
  QString workingLine = line;

  list.clear();
  if (!m_separatorsRegexp.isValid()) {
	  list << line;
	  return true;
  }

  while (!workingLine.isEmpty()) {
	if (workingLine[0] == m_textDelimiter) {
	  // Look for next delimiter
	  int idx = workingLine.indexOf(m_textDelimiter, 1);
	  // Delimiter is not found
	  if (idx == -1) {
		qDebug() << "Can not found delimiter " << m_textDelimiter 
				 << " in " << workingLine;
		return false;
	  }
	  // Check that next element is a separator or eol
	  QString word = workingLine.mid(1, idx-1);
	  workingLine.remove(0, idx+1);
	  list << word;

	  QString sep = workingLine.left(1);
	  if (m_separatorsRegexp.exactMatch(sep)) {
		// Remove this separator
		workingLine.remove(0, 1);
	  } else if (!workingLine.isEmpty()) {
		// separator is not there and its not the end of the string: error
		qDebug() << "Can not found separators " << m_separators 
				 << " in " << workingLine;
		return false;
	  }
	} else {
	  // Look for a separator
	  int idx = workingLine.indexOf(m_separatorsRegexp);
	  if (idx == -1) {
		list << workingLine;
		workingLine.clear();
	  } else {
		QString word = workingLine.left(idx);
		workingLine.remove(0, idx+1);
		list << word;
	  }
	}
  }

  return true;
}
