/* -*- c++ -*-
 *
 *  Le Caviste --- a wine cellar managing application
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  For more information, visit the Le Caviste Home Page at
 *  http://www.lecaviste.org/
 *
 *  Copyright (c) 2007
 *      Le Caviste Authors <devel@lecaviste.org>
 *
 */
#ifndef IMPORT_WIZARD_HPP
#define IMPORT_WIZARD_HPP

#include <QtGui>

class ImportWizard : public QWizard
{
  Q_OBJECT

public:
  ImportWizard(QWidget * = 0);
  void setTextFile(const QString & fileName) { m_fileName = fileName; }

  QString separators(void) { return m_separators; }
  int startingLine(void) { return m_startingLine; }
  QChar delimiter(void) { return m_delimiter; }
  QHash<int, int> columnDefinition(void) { return m_columnDefinition; }

protected slots:
  void onCustomSeparatorClicked(void);
  void onSeparatorBoxClicked(void);
  void onTextDelimiterRadioClicked(void);
  void onStartingLineChanged(int);
  void onColumnAssociationChanged(int);

protected:
  QWizardPage * createSeparatorPage(void);
  QWizardPage * createColumnAssociationPage(void);
  void initializePage(int);
  void updateModel(void);

  enum {
	SeparatorPage 			= 0,
	ColumnAssociationPage 	= 1
  };

private:
  QString 			m_fileName;
  QString			m_separators;
  int 				m_startingLine;
  QChar				m_delimiter;
  QHash<int, int>	m_columnDefinition;
  QSpinBox *		m_startingLineSpinBox;
  QCheckBox * 		m_spaceBox;
  QCheckBox * 		m_tabularBox;
  QCheckBox * 		m_bangBox;
  QCheckBox * 		m_commaBox;
  QCheckBox * 		m_colonBox;
  QCheckBox * 		m_hyphenBox;
  QCheckBox * 		m_semicolonBox;
  QCheckBox * 		m_pipeBox;
  QCheckBox * 		m_customBox;
  QLineEdit * 		m_customField;
  QRadioButton *	m_doublequote;
  QRadioButton *	m_quote;
  QRadioButton *	m_backquote;
  QTableWidget *	m_exampleTable;
  QTableWidget *	m_columnTable;
};

#endif
