/* -*- c++ -*-
 *
 *  Le Caviste --- a wine cellar managing application
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  For more information, visit the Le Caviste Home Page at
 *  http://www.lecaviste.org/
 *
 *  Copyright (c) 2007
 *      Le Caviste Authors <devel@lecaviste.org>
 *
 */
#ifndef LECAVISTE_WINDOW_HPP
#define LECAVISTE_WINDOW_HPP

#include <QtGui>
#include <QtSql>

#include "cellar.hpp"
#include "preferences.hpp"
#include "printer.hpp"

class LeCavisteWindow: public QMainWindow
{
  Q_OBJECT

public:
  LeCavisteWindow();

  void openFile(const QString & name) {
	loadFile(name);
  }
  
private slots:
  // Actions
  // File menu
  void onActionNew(void);
  void onActionOpen(void);
  void onActionOpenRecentFile(void);
  void onActionImport(void);
  void onActionExportCSV(void);
  void onActionPreferences(void);
  void onActionPrint(void);
  void onActionPrintPreview(void);
  void onActionPageSetup(void);

  // Wine menu
  void onActionAddWine(void);
  void onActionEditWine(void);
  void onActionDeleteWine(void);
  void onActionDrinkBottle(void);
  void onActionAddAppellation(void);
  void onActionAddProductor(void);
  void onActionAddCountry(void);
  void onActionAddPlace(void);

  void onActionShowAppellations(void);
  void onActionShowProductors(void);
  void onActionShowCountries(void);
  void onActionShowPlaces(void);

  // Display menu
  void onActionCollapse(void);
  void onActionExpand(void);

  void onActionSortByName(void);
  void onActionSortByAppellation(void);
  void onActionSortByCategory(void);
  void onActionSortByCountry(void);
  void onActionSortByPlace(void);
  
  // Help menu
  void onActionAbout(void);
  void onActionHelp(void);


  void onWineDoubleClicked(const QModelIndex& index);
  void onCurrentRowChanged(const QModelIndex& index);

protected:
  typedef enum
	{
	  DisplayMode_Name			= 0,
	  DisplayMode_Appellation   = 1,
	  DisplayMode_Category		= 2,
	  DisplayMode_Country		= 3,
	  DisplayMode_Place			= 4
	} DisplayMode;

  enum {
	MaxRecentFiles = 4,
	ColumnsCount = 15
  };

  bool loadFile(const QString &);
  bool newFile(const QString &);
  void createUI(void);
  void createSqlModel(void);
  void updateFilter(void);
  void closeEvent(QCloseEvent *);
  void changeDisplayMode(DisplayMode);
  void updateRecentFileActions(void);
  void updateMenus(void);
  void updateSortActions(QAction *);
  void setCurrentFile(const QString &);
  void updateStats(void);

  void writeSettings(void);
  void readSettings(void);
  void readViewSettings(void);

private:
  // UI
  QAction *			m_actionOpen;
  QAction *			m_actionOpenRecentFile[MaxRecentFiles];
  QAction *			m_actionSepartor;
  QAction *			m_actionNew;
  QAction *			m_actionImport;
  QAction *			m_actionExportCSV;
  QAction *			m_actionPreferences;
  QAction *			m_actionPrint;
  QAction *			m_actionPrintPreview;
  QAction *			m_actionPageSetup;
  QAction *			m_actionQuit;
  QAction *			m_actionExpand;
  QAction *			m_actionCollapse;
  QAction *         m_actionAddWine;
  QAction *         m_actionEditWine;
  QAction *         m_actionDeleteWine;
  QAction *         m_actionDrinkBottle;
  QAction *         m_actionAddAppellation;
  QAction *         m_actionAddProductor;
  QAction *         m_actionAddCountry;
  QAction *         m_actionAddPlace;
  QAction *         m_actionShowAppellations;
  QAction *         m_actionShowProductors;
  QAction *         m_actionShowCountries;
  QAction *         m_actionShowPlaces;
  QAction * 		m_actionSortByName;
  QAction * 		m_actionSortByAppellation;
  QAction * 		m_actionSortByCategory;
  QAction * 		m_actionSortByCountry;
  QAction * 		m_actionSortByPlace;
  QAction *			m_actionAbout;
  QAction *			m_actionHelp;
  QMenuBar *		m_menubar;
  QStatusBar *		m_statusbar;
  QLabel *			m_stats;
  QToolBar *		m_toolBar;
  
  QTreeView *		m_winesView;
  QString			m_appName;
  bool				m_listSaved;
  Cellar 			m_cellar;
  Preferences		m_preferences;
  Printer *			m_printer;

  QStringList		m_recentFiles;
  DisplayMode		m_currentDisplayMode;
};

#endif
