/* -*- c++ -*-
 *
 *  Le Caviste --- a wine cellar managing application
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  For more information, visit the Le Caviste Home Page at
 *  http://www.lecaviste.org/
 *
 *  Copyright (c) 2007
 *      Le Caviste Authors <devel@lecaviste.org>
 *
 */
#include "place_dialog.hpp"
#include "cellar.hpp"

PlaceDialog::PlaceDialog (
	Cellar * cellar, 
	QWidget * parent
) : QDialog(parent), m_cellar(cellar), m_placeIdx(-1)
{
  m_model = cellar->places();
  
  createUI();
  m_title = tr("Add place");
  setWindowTitle(tr("Add place"));
}

PlaceDialog::PlaceDialog (
	Cellar * cellar, 
	int id,
	QWidget * parent
) : QDialog(parent), m_cellar(cellar), m_placeIdx(id)
{
  m_model = cellar->places();
  
  createUI();
  
#ifdef DEBUG
  m_title = tr("Edit Place (%1)").arg(id);
#else
  m_title = tr("Edit Place");
#endif
  setWindowTitle(tr("Edit place"));
  fillPlace();
}

void PlaceDialog::createUI(void)
{

  QGroupBox * box = new QGroupBox(m_title);

  QLabel * nameLabel = new QLabel(tr("Name:"));
  m_name = new QLineEdit;

  QGridLayout * boxLayout = new QGridLayout;
  int idx = 0;
  boxLayout->addWidget(nameLabel, idx, 0, Qt::AlignTop);
  boxLayout->addWidget(m_name, idx++, 1);
  box->setLayout(boxLayout);

  // Create buttons
  QPushButton * closeButton = new QPushButton(tr("&Close"));
  QPushButton * validateButton = new QPushButton(tr("&Ok"));
  
  connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
  connect(validateButton, SIGNAL(clicked()), this, SLOT(submit()));
  
  QDialogButtonBox * buttonBox = new QDialogButtonBox;
  buttonBox->addButton(validateButton, QDialogButtonBox::ApplyRole);
  buttonBox->addButton(closeButton, QDialogButtonBox::RejectRole);
  
  // Create main layout
  QVBoxLayout * layout = new QVBoxLayout;
  layout->addWidget(box);
  layout->addWidget(buttonBox);
  setLayout(layout);
}

void PlaceDialog::fillPlace(void)
{
  QSqlQuery query;
  // Get selected place infos
  QSqlRecord record = m_model->record(m_placeIdx);
  m_name->setText(record.value(Cellar::PlaceColumn_Name).toString());
}

void PlaceDialog::submit(void)
{
  QString name = m_name->text();
  
  if (name.isEmpty()) {
	  QString message(tr("Please provide the name of the place."));
	  QMessageBox::information(this, m_title, message);
  } else {
	int foundId = m_cellar->findPlaceId(name);
	if (m_placeIdx != -1) {
	  QSqlRecord record = m_model->record(m_placeIdx);
	  int id = record.value("id").toInt();
	  // This is the samed edit entry
	  if (foundId == id) {
		accept();
		return;
	  }
	}

	if (foundId != -1) {
	  QMessageBox::information(this, 
							   m_title, 
							   tr("Place \"%1\" already exists").arg(name));
	  return;
	}
	QSqlRecord record;
	
	QSqlField f1("name", QVariant::String);
	
	f1.setValue(QVariant(name));
    record.append(f1);

	if (m_placeIdx == -1) {
	  m_model->insertRecord(-1, record);
	}
	else {
	  m_model->setRecord(m_placeIdx, record);
	}

	m_place = name;
	m_model->submitAll();
	accept();
  }
}

