/* -*- c++ -*-
 *
 *  Le Caviste --- a wine cellar managing application
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  For more information, visit the Le Caviste Home Page at
 *  http://www.lecaviste.org/
 *
 *  Copyright (c) 2007
 *      Le Caviste Authors <devel@lecaviste.org>
 *
 */
#include "preferences_dialog.hpp"
#include "preferences_pages.hpp"

PreferencesDialog::PreferencesDialog(Preferences & pref, QWidget * parent)
  : QDialog(parent)
{
  createUI(pref);
  setWindowTitle(tr("Le Caviste Preferences"));
}


void PreferencesDialog::createUI(Preferences & pref)
{
  m_contentsWidget = new QListWidget(this);
  m_contentsWidget->setViewMode(QListView::IconMode);
  m_contentsWidget->setIconSize(QSize(80, 32));
  m_contentsWidget->setMovement(QListView::Static);
  m_contentsWidget->setMaximumWidth(80);
  m_contentsWidget->setSpacing(12);
  
  m_pagesWidget = new QStackedWidget(this);
  m_pagesWidget->addWidget(new GeneralPage(pref, this));
  m_pagesWidget->addWidget(new WinesListPage(pref, this));
  
  QPushButton * closeButton = new QPushButton(tr("Close"));
  connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));

  QListWidgetItem * generalButton = new QListWidgetItem(m_contentsWidget);
  generalButton->setIcon(QIcon(":/images/icons/config.png"));
  generalButton->setText(tr("General"));
  generalButton->setTextAlignment(Qt::AlignHCenter);
  generalButton->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
  
  QListWidgetItem * winesListButton = new QListWidgetItem(m_contentsWidget);
  winesListButton->setIcon(QIcon(":/images/icons/wine-32.png"));
  winesListButton->setText(tr("Wines"));
  winesListButton->setTextAlignment(Qt::AlignHCenter);
  winesListButton->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
  
  connect(m_contentsWidget,
		  SIGNAL(currentItemChanged(QListWidgetItem *, QListWidgetItem *)),
		  this, SLOT(changePage(QListWidgetItem *, QListWidgetItem*)));
  
  m_contentsWidget->setCurrentRow(0);

  QHBoxLayout * horizontalLayout = new QHBoxLayout();
  horizontalLayout->addWidget(m_contentsWidget);
  horizontalLayout->addWidget(m_pagesWidget);
  
  QHBoxLayout * buttonsLayout = new QHBoxLayout();
  buttonsLayout->addStretch(1);
  buttonsLayout->addWidget(closeButton);

  QVBoxLayout * mainLayout = new QVBoxLayout(this);
  mainLayout->addLayout(horizontalLayout);
  mainLayout->addLayout(buttonsLayout);
  setLayout(mainLayout);
}


void PreferencesDialog::changePage(
	QListWidgetItem * current, 
	QListWidgetItem * previous)
{
  if (!current)
	current = previous;
  
  m_pagesWidget->setCurrentIndex(m_contentsWidget->row(current));
}

void PreferencesDialog::resizeEvent(QResizeEvent * event) {
	qDebug() << "event" << event->size();
}

