/* -*- c++ -*-
 *
 *  Le Caviste --- a wine cellar managing application
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  For more information, visit the Le Caviste Home Page at
 *  http://www.lecaviste.org/
 *
 *  Copyright (c) 2007
 *      Le Caviste Authors <devel@lecaviste.org>
 *
 */
#include "preferences_pages.hpp"

GeneralPage::GeneralPage(Preferences & pref, QWidget *parent)
  : QWidget(parent), m_pref(&pref)
{
  QGroupBox * configGroup = new QGroupBox(tr("General configuration"));
 
  QLabel * startingLabel = new QLabel(tr("At Startup:"));
  QComboBox * startingCombo = new QComboBox;
  startingCombo->addItem(tr("Do nothing"));
  startingCombo->addItem(tr("Open the latest cellar"));
  //  startingCombo->addItem(tr("Open the cellar:"));
  
  if (pref.openLatestCellar()) {
	startingCombo->setCurrentIndex(1);
  } else {
	startingCombo->setCurrentIndex(0);
  }
  connect(startingCombo, SIGNAL(activated(int)),
		  this, SLOT(onStartingActivated(int)));

  QHBoxLayout * startingLayout = new QHBoxLayout;
  startingLayout->addWidget(startingLabel);
  startingLayout->addWidget(startingCombo);
  
  QVBoxLayout * configLayout = new QVBoxLayout;
  configLayout->addLayout(startingLayout);
  configGroup->setLayout(configLayout);
  
  QVBoxLayout * mainLayout = new QVBoxLayout;
  mainLayout->addWidget(configGroup);
  mainLayout->addStretch(1);
  setLayout(mainLayout);
}

void GeneralPage::onStartingActivated(int index)
{
  if (index == 0) {
	m_pref->setOpenLatestCellar(false);
  } else if (index == 1) {
	m_pref->setOpenLatestCellar(true);
  } else {
	qDebug() << "This should not occured";
  }
}

WinesListPage::WinesListPage(Preferences & pref, QWidget *parent)
  : QWidget(parent), m_pref(&pref)
{
  QGroupBox * configGroup = new QGroupBox(tr("Wines list configuration"));
  
  QCheckBox * checkbox = new QCheckBox(tr("Display wines whose quantity is 0"));
  if (pref.displayNullQuantityWines()) {
	checkbox->setCheckState(Qt::Checked);
  } else {
	checkbox->setCheckState(Qt::Unchecked);
  }

  connect(checkbox, SIGNAL(stateChanged(int)),
		  this, SLOT(onDisplayNullQuantityWinesChanged(int)));

  QVBoxLayout * configLayout = new QVBoxLayout;
  configLayout->addWidget(checkbox);
  configGroup->setLayout(configLayout);
  
  QVBoxLayout * mainLayout = new QVBoxLayout;
  mainLayout->addWidget(configGroup);
  mainLayout->addStretch(1);
  setLayout(mainLayout);
}

void WinesListPage::onDisplayNullQuantityWinesChanged(int state)
{
  m_pref->setDisplayNullQuantityWines(state == Qt::Checked);
}
