/* -*- c++ -*-
 *
 *  Le Caviste --- a wine cellar managing application
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  For more information, visit the Le Caviste Home Page at
 *  http://www.lecaviste.org/
 *
 *  Copyright (c) 2007
 *      Le Caviste Authors <devel@lecaviste.org>
 *
 */
#ifndef PREVIEW_VIEW_HPP
#define PREVIEW_VIEW_HPP

#include <QtGui>

class PreviewView : public QAbstractScrollArea
{
  Q_OBJECT

public:
  PreviewView(QPrinter &);
  
  inline void updateLayout() { setup();
	resizeEvent(0); viewport()->update(); }

public slots:
  void zoomIn();
  void zoomOut();
  void setNumberOfPages(int count);
  
signals:
  void pageRequested(int index, QPainter &painter);
  
protected:
  virtual void paintEvent(QPaintEvent *e);
  virtual void resizeEvent(QResizeEvent *);
  virtual void mousePressEvent(QMouseEvent *e);
  virtual void mouseMoveEvent(QMouseEvent *e);
  virtual void mouseReleaseEvent(QMouseEvent *e);
  
  void paintPage(QPainter &painter, int page);
  void setup(void);

private:
  QSizeF 	m_paperSize;
  QPointF 	m_pageTopLeft;

  int 		m_pageCount;
  qreal 	m_scale;
  int 		m_interPageSpacing;
  QPoint 	m_mousePressPos;
  QPoint 	m_scrollBarValuesOnMousePress;
  QPrinter& m_printer;
};

#endif // #ifndef PREVIEW_VIEW_HPP
