/* -*- c++ -*-
 *
 *  Le Caviste --- a wine cellar managing application
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  For more information, visit the Le Caviste Home Page at
 *  http://www.lecaviste.org/
 *
 *  Copyright (c) 2007
 *      Le Caviste Authors <devel@lecaviste.org>
 *
 */
#include "preview_window.hpp"
#include "preview_view.hpp"

PreviewWindow::PreviewWindow(QPrinter & printer, QWidget *parent)
  : QMainWindow(parent)
{
    setWindowTitle(tr("Le Caviste - Print Preview"));

    m_view = new PreviewView(printer);
    setCentralWidget(m_view);
    resize(800, 600);

    QToolBar *tb = addToolBar(tr("Print"));
    tb->setToolButtonStyle(Qt::ToolButtonIconOnly);

    QAction *a;
    a = new QAction(QIcon(":/images/icons/printer.png"),
					tr("&Print..."), 
					this);
    a->setShortcut(Qt::CTRL + Qt::Key_P);
    connect(a, SIGNAL(triggered()), this, SIGNAL(printRequired()));
    tb->addAction(a);

	a = new QAction(QIcon(":/images/icons/printer_setup.png"), 
					tr("Page setup ..."), 
					this);
    connect(a, SIGNAL(triggered()), this, SLOT(pageSetup()));
    tb->addAction(a);

    tb->addSeparator();

    a = new QAction(QIcon(":/images/icons/zoom_in.png"), 
					tr("Zoom In"), 
					this);
    connect(a, SIGNAL(triggered()), m_view, SLOT(zoomIn()));
    tb->addAction(a);

    a = new QAction(QIcon(":/images/icons/zoom_out.png"), 
					tr("Zoom Out"), 
					this);
    connect(a, SIGNAL(triggered()), m_view, SLOT(zoomOut()));
    tb->addAction(a);

    tb->addSeparator();

    a = new QAction(QIcon(":/images/icons/cancel.png"), 
					tr("&Close"), 
					this);
    a->setShortcut(Qt::CTRL + Qt::Key_W);
    connect(a, SIGNAL(triggered()), this, SLOT(close()));
    tb->addAction(a);

    statusBar()->setSizeGripEnabled(true);
}

void PreviewWindow::pageSetup()
{
  emit setupRequired();
  m_view->updateLayout();
  raise();
}
