#ifndef PRINT_PAGE_HPP
#define PRINT_PAGE_HPP

class PrintPage {
public:
  PrintPage(void)
  { 
	clear();
  }

  bool empty(void) { 
	return m_rows.isEmpty(); 
  }
  void clear(void) {
	m_rowStart = 0;
	m_rowEnd = 0;
	m_colStart = -1;
	m_colEnd = -1;
	m_rows.clear();
	m_rowsCount = 0;
  }
  
  void append(const QString & s) {
	m_rows.append(s);
	if (!s.isEmpty() && !s.isNull())
	  m_rowsCount++;
  }

  void append(int r) {
	if (m_rows.isEmpty()) {
	  m_rowStart = m_rowEnd = r;
	} else {
	  m_rowStart = qMin(m_rowStart, r);
	  m_rowEnd = qMax(m_rowEnd, r);
	}
	m_rows.append(r);
	m_rowsCount++;
  }
  void setRowRange(int s, int e) {
	for(int i=s; i<=e; i++) {
	  append(i);
	}
  }
  int rowStart(void) const { return m_rowStart; }
  int rowEnd(void) const { return m_rowEnd; }
  int colStart(void) const { return m_colStart; }
  int colEnd(void) const { return m_colEnd; }
  void setColRange(int s, int e) { m_colStart = s; m_colEnd = e; }
  int rowsCount(void) { return m_rowsCount; }
  QList<QVariant> rows() const { return m_rows; }

private:
  QList<QVariant> m_rows;
  int m_rowStart;
  int m_rowEnd;
  int m_colStart;
  int m_colEnd;
  int m_rowsCount;
};

inline QDebug operator<<(QDebug s, const PrintPage& p) 
{
  s << "PrintPage(" << p.rowStart() << "," << p.rowEnd() << "-" 
	<< p.colStart() << "," << p.colEnd() << ")";
  return s;
}

#endif
