/* -*- c++ -*-
 *
 *  Le Caviste --- a wine cellar managing application
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  For more information, visit the Le Caviste Home Page at
 *  http://www.lecaviste.org/
 *
 *  Copyright (c) 2007
 *      Le Caviste Authors <devel@lecaviste.org>
 *
 */
#ifndef PRINTER_HPP
#define PRINTER_HPP

#include <QtGui>
#include <QtSql>

#include "cellar.hpp"

class PrintPage;

class Printer: public QObject
{
  Q_OBJECT

public:
  Printer(QTreeView *, QWidget * = NULL);
  ~Printer(void);

  void setSorted(bool v) {
	m_sorted = v;
  }

public slots:
  void printPage(int index, QPainter &painter);
  void paginate(QPrinter &printer);
  void setup(void);
  void print (void);
  void preview(void);

signals:
  void pagesCountChanged(int);

private:
  enum PageOrder { LeftToRight = 0, TopToBottom = 1};
  static const int smallGap = 5;

  int computeColsWidth(QPainter * painter);
  inline int mmToPixels(int mm, QPaintDevice *device) {
	// Convert to inches first
    return qRound(mm*0.039370147 * device->logicalDpiY());
  }

  QWidget * 					m_parent;
  QTreeView * 					m_winesView;
  QSqlRelationalTableModel * 	m_model;
  QList<PrintPage>				m_pages;
  QList<int> 					m_colsWidth;
  QPrinter * 					m_printer;
  QHeaderView * 				m_headerView;
  bool 							m_sorted;
  int m_logicalSortedCol;
  // Page setup
  int m_pageOrder;
  int m_fontSize;
  int m_scale; 
  
  int m_marginLeft;
  int m_currentMarginLeft;
  int m_marginRight;  
  int m_marginTop;
  int m_marginBottom;  

  int m_lineHeight;
  int m_linesPerPage;
  int m_pageWidth;
  int m_pageTotalWidth;
  int m_pageHeight;
  int m_pageTotalHeight;
};


#endif

