/* -*- c++ -*-
 *
 *  Le Caviste --- a wine cellar managing application
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  For more information, visit the Le Caviste Home Page at
 *  http://www.lecaviste.org/
 *
 *  Copyright (c) 2007
 *      Le Caviste Authors <devel@lecaviste.org>
 *
 */
#include "productor_dialog.hpp"


ProductorDialog::ProductorDialog (
	Cellar * cellar, 
	QWidget * parent
) : QDialog(parent), m_cellar(cellar), m_productorIdx(-1)
{
  m_model = cellar->productors();
  
  createUI();
  setWindowTitle(tr("Add productor"));
}

ProductorDialog::ProductorDialog (
	Cellar * cellar, 
	int id,
	QWidget * parent
) : QDialog(parent), m_cellar(cellar), m_productorIdx(id)
{
  m_model = cellar->productors();
  
  createUI();
  
#ifdef DEBUG
  m_groupBox->setTitle(tr("Edit Productor (%1)").arg(id));
#else
  m_groupBox->setTitle(tr("Edit Productor"));
#endif
  setWindowTitle(tr("Edit productor"));
  fillProductor();
}

void ProductorDialog::createUI(void)
{

  m_groupBox = new QGroupBox(tr("Add Productor"));

  QLabel * nameLabel = new QLabel(tr("Name:"));
  m_name = new QLineEdit;
  QLabel * addressLabel = new QLabel(tr("Address:"));
  m_address = new QTextEdit;
  m_address->setTabChangesFocus(true);
  m_address->setAcceptRichText(false);
  QLabel * phoneLabel = new QLabel(tr("Phone:"));
  m_phone = new QLineEdit;
  QLabel * faxLabel = new QLabel(tr("Fax:"));
  m_fax = new QLineEdit;
  QLabel * emailLabel = new QLabel(tr("Email:"));
  m_email = new QLineEdit;

  QGridLayout * boxLayout = new QGridLayout;
  int idx = 0;
  boxLayout->addWidget(nameLabel, idx, 0, Qt::AlignTop);
  boxLayout->addWidget(m_name, idx++, 1);
  boxLayout->addWidget(addressLabel, idx, 0, Qt::AlignTop);
  boxLayout->addWidget(m_address, idx++, 1);
  boxLayout->addWidget(emailLabel, idx, 0, Qt::AlignTop);
  boxLayout->addWidget(m_email, idx++, 1);
  boxLayout->addWidget(phoneLabel, idx, 0, Qt::AlignTop);
  boxLayout->addWidget(m_phone, idx++, 1);
  boxLayout->addWidget(faxLabel, idx, 0, Qt::AlignTop);
  boxLayout->addWidget(m_fax, idx++, 1);
  m_groupBox->setLayout(boxLayout);

  int fontHeight = QFontMetrics(m_address->currentFont()).height();
  // Set height to 5 lines
  m_address->setMaximumHeight (5*fontHeight);
   
  // Create buttons
  QPushButton * closeButton = new QPushButton(tr("&Close"));
  QPushButton * validateButton = new QPushButton(tr("&Ok"));
  
  connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
  connect(validateButton, SIGNAL(clicked()), this, SLOT(submit()));
  
  QDialogButtonBox * buttonBox = new QDialogButtonBox;
  buttonBox->addButton(validateButton, QDialogButtonBox::ApplyRole);
  buttonBox->addButton(closeButton, QDialogButtonBox::RejectRole);
  
  // Create main layout
  QVBoxLayout * layout = new QVBoxLayout;
  layout->addWidget(m_groupBox);
  layout->addWidget(buttonBox);
  setLayout(layout);
}

void ProductorDialog::fillProductor(void)
{
  QSqlQuery query;
  // Get selected productor infos
  QSqlRecord record = m_model->record(m_productorIdx);
  m_name->setText(
	record.value(Cellar::ProductorColumn_Name).toString());
  m_address->setText(
	record.value(Cellar::ProductorColumn_Address).toString());
  m_email->setText(
	record.value(Cellar::ProductorColumn_Email).toString());
  m_phone->setText(
	record.value(Cellar::ProductorColumn_Phone).toString());
  m_fax->setText(
	record.value(Cellar::ProductorColumn_Fax).toString());
}


void ProductorDialog::submit(void)
{
  QString name = m_name->text();
  
  if (name.isEmpty()) {
	  QString message(tr("Please provide the name of the productor."));
	  QMessageBox::information(this, tr("Add productor"), message);
  } else {
	QSqlRecord record;
	
	QSqlField f1("name", QVariant::String);
	QSqlField f2("address", QVariant::String);
	QSqlField f3("phone", QVariant::String);
	QSqlField f4("fax", QVariant::String);
	QSqlField f5("email", QVariant::String);
	
	f1.setValue(QVariant(name));
	f2.setValue(QVariant(m_address->toPlainText()));
	f3.setValue(QVariant(m_phone->text()));
    f4.setValue(QVariant(m_fax->text()));
    f5.setValue(QVariant(m_email->text()));
    record.append(f1);
    record.append(f2);
    record.append(f3);
    record.append(f4);
    record.append(f5);

	if (m_productorIdx == -1) {
	  m_model->insertRecord(-1, record);
	} else {
	  m_model->setRecord(m_productorIdx, record);
	}

	m_productor = name;
	m_model->submitAll();
	accept();
  }
}

