/* -*- c++ -*-
 *
 *  Le Caviste --- a wine cellar managing application
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  For more information, visit the Le Caviste Home Page at
 *  http://www.lecaviste.org/
 *
 *  Copyright (c) 2007
 *      Le Caviste Authors <devel@lecaviste.org>
 *
 */
#ifndef WINE_DIALOG_HPP
#define WINE_DIALOG_HPP

#include <QtGui>
#include <QtSql>

#include "cellar.hpp"

class WineDialog: public QDialog 
{
  Q_OBJECT

public:
  WineDialog (Cellar *, QWidget *);
  WineDialog (Cellar *, int index, QWidget *);

private slots:
  void submit(void);
  void onAddAppellation(void);
  void onAddProductor(void);
  void onAddCountry(void);
  void onAddPlace(void);
  void onAppellationChanged(const QString &);
  void onMillesimeCheckBoxChanged(int);
  
protected:
  void createUI(void);
  void fillWine(void);

private:
  Cellar *		m_cellar;
  int 			m_wineIdx;
  QString		m_title;
  QLineEdit *	m_name;
  QSpinBox *  	m_millesime;
  QCheckBox *	m_millesimeCheckBox;
  QComboBox *	m_category;
  QComboBox *   m_appellation;
  QComboBox *	m_volume;
  QComboBox * 	m_productor;
  QComboBox * 	m_country;
  QComboBox *	m_place;
  QSpinBox *    m_quantity;
  QSpinBox *    m_boughtQuantity;
  QLineEdit *	m_boughtPrice;
  QDateEdit *	m_boughtDate;
  QSpinBox *	m_bestBefore;
  QTextEdit *	m_comment;
  QSqlRelationalTableModel * m_model;
};

#endif
